@@ -2,7 +2,7 @@ package Term::Title;
 use strict;
 use warnings;
 # ABSTRACT: Portable API to set the terminal titlebar
-our $VERSION = '0.05'; # VERSION
+our $VERSION = '0.06'; # VERSION
 
 use Exporter;
 our @ISA = 'Exporter';
@@ -95,11 +95,11 @@ Term::Title - Portable API to set the terminal titlebar
 
 =head1 VERSION
 
-version 0.05
+version 0.06
 
 =head1 SYNOPSIS
 
-    use Term::Title 'set_titlebar';
+    use Term::Title 'set_titlebar', 'set_tab_title';
 
     set_titlebar("This goes into the title");
 
